@@ -31,7 +31,7 @@ def VQTLogfunc(msg):
     c_s = msg.decode()
     # cs = str(c_s,'utf-8')
     cs = str(c_s)
-    #print('VQTLogfunc : ' + cs)
+    print('VQTLogfunc : ' + cs)
     global connect_flag
     global stop_flag1
     if 'Connected' in cs or 'Message sent' in cs:
