@@ -1,6 +1,8 @@
 
 import sys
-sys.path.append('..')
+import  os
+from os import  path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 from formatConvert.wav_pcm import wav2pcm,pcm2wav
 from G160.G160 import cal_g160
 from P563.P563 import cal_563_mos
